@@ -1,7 +1,9 @@
 assert <- function(x, y) {
   if (!is.null(x)) {
     if (!inherits(x, y)) {
-      stop(deparse(substitute(x)), " must be of class ",
+      stop(
+        deparse(substitute(x)),
+        " must be of class ",
         paste0(y, collapse = ", "),
         call. = FALSE
       )
